@@ -12,13 +12,6 @@
 # along with this software. If not, see
 # <http://creativecommons.org/publicdomain/zero/1.0/>.
 
-"""Split-screen Example
-
-This is an example of split-screening being used, where two players see
-two different parts of the room.
-
-"""
-
 from __future__ import division
 from __future__ import absolute_import
 from __future__ import print_function
@@ -32,7 +25,7 @@ class Game(sge.Game):
     def event_game_start(self):
         self.mouse.sprite = "circle"
 
-    def event_step(self, time_passed):
+    def event_step(self, time_passed, delta_mult):
         self.project_line(self.width / 2, 0, self.width / 2, self.height,
                           "black", thickness=3)
         self.project_line(0, self.height / 2, self.width, self.height / 2,
@@ -54,16 +47,15 @@ class Circle(sge.StellarClass):
         self.image_alpha = 128
 
     def set_color(self):
-        self.image_blend = self.normal_image_blend
-        for obj in sge.game.current_room.objects_by_class[Circle]:
-            if obj is not self and self.collides(obj):
-                self.image_blend = 'olive'
-                break
+        if self.collision(Circle):
+            self.image_blend = 'olive'
+        else:
+            self.image_blend = self.normal_image_blend
 
     def event_create(self):
         self.set_color()
 
-    def event_step(self, time_passed):
+    def event_step(self, time_passed, delta_mult):
         left_key = ['left', 'a', 'j', 'kp_4'][self.player]
         right_key = ['right', 'd', 'l', 'kp_6'][self.player]
         up_key = ['up', 'w', 'i', 'kp_8'][self.player]
