@@ -999,6 +999,11 @@ class Game:
         more information.
 
         """
+        outline_thickness = abs(outline_thickness)
+        draw_x = outline_thickness // 2
+        draw_y = outline_thickness // 2
+        x -= draw_x
+        y -= draw_y
         sprite = self._get_rectangle_sprite(width, height, fill, outline,
                                             outline_thickness)
         self.project_sprite(sprite, 0, x, y)
@@ -1025,6 +1030,11 @@ class Game:
         more information.
 
         """
+        outline_thickness = abs(outline_thickness)
+        draw_x = outline_thickness // 2
+        draw_y = outline_thickness // 2
+        x -= draw_x
+        y -= draw_y
         sprite = self._get_ellipse_sprite(width, height, fill, outline,
                                           outline_thickness, anti_alias)
         self.project_sprite(sprite, 0, x, y)
@@ -1660,12 +1670,10 @@ class Game:
             outline_thickness = abs(outline_thickness)
             draw_x = outline_thickness // 2
             draw_y = outline_thickness // 2
-            x -= draw_x
-            y -= draw_y
             w = width + outline_thickness
             h = height + outline_thickness
             sprite = sge.Sprite(None, width=w, height=h)
-            sprite.draw_rectangle(draw_x, draw_y, w, h, fill, outline,
+            sprite.draw_rectangle(draw_x, draw_y, width, height, fill, outline,
                                   outline_thickness)
             self._rectangle_cache[i] = sprite
             sprite.destroy()
@@ -1682,12 +1690,10 @@ class Game:
             outline_thickness = abs(outline_thickness)
             draw_x = outline_thickness // 2
             draw_y = outline_thickness // 2
-            x -= draw_x
-            y -= draw_y
             w = width + outline_thickness
             h = height + outline_thickness
             sprite = sge.Sprite(None, width=w, height=h)
-            sprite.draw_ellipse(draw_x, draw_y, w, h, fill, outline,
+            sprite.draw_ellipse(draw_x, draw_y, width, height, fill, outline,
                                 outline_thickness)
             self._ellipse_cache[i] = sprite
             sprite.destroy()
