@@ -15,6 +15,11 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with the Pygame SGE.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import division
+from __future__ import absolute_import
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import os
 
 import pygame
@@ -25,7 +30,7 @@ import sge
 __all__ = ['Music']
 
 
-class Music:
+class Music(object):
 
     """Music handling class.
 
