@@ -15,11 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with the Pygame SGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import pygame
 
 import sge
@@ -28,7 +23,7 @@ import sge
 __all__ = ['Room']
 
 
-class Room(object):
+class Room:
 
     """Class for rooms.
 
@@ -175,8 +170,8 @@ class Room(object):
 
         size = self._collision_area_size
         self._collision_areas = []
-        for i in xrange(0, self.width, size):
-            column = [[] for j in xrange(0, self.height, size)]
+        for i in range(0, self.width, size):
+            column = [[] for j in range(0, self.height, size)]
             self._collision_areas.append(column)
 
         # The "Void" is the area outside the room.  This area is
@@ -367,6 +362,11 @@ class Room(object):
         more information.
 
         """
+        outline_thickness = abs(outline_thickness)
+        draw_x = outline_thickness // 2
+        draw_y = outline_thickness // 2
+        x -= draw_x
+        y -= draw_y
         sprite = sge.game._get_rectangle_sprite(width, height, fill, outline,
                                                 outline_thickness)
         self.project_sprite(sprite, 0, x, y, z)
@@ -394,6 +394,11 @@ class Room(object):
         more information.
 
         """
+        outline_thickness = abs(outline_thickness)
+        draw_x = outline_thickness // 2
+        draw_y = outline_thickness // 2
+        x -= draw_x
+        y -= draw_y
         sprite = sge.game._get_ellipse_sprite(width, height, fill, outline,
                                               outline_thickness, anti_alias)
         self.project_sprite(sprite, 0, x, y, z)
