@@ -15,6 +15,11 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with the Pygame SGE.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import division
+from __future__ import absolute_import
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import os
 import warnings
 
@@ -26,7 +31,7 @@ import sge
 __all__ = ['Sprite']
 
 
-class Sprite:
+class Sprite(object):
 
     """Class which holds information for images and animations.
 
@@ -64,16 +69,6 @@ class Sprite:
           :attr:`image_yscale` attribute of a :class:`sge.StellarClass`
           object instead.
 
-    .. attribute:: origin_x
-
-       The horizontal location of the origin relative to the left edge
-       of the images.
-
-    .. attribute:: origin_y
-
-       The vertical location of the origin relative to the top edge of
-       the images.
-
     .. attribute:: transparent
 
        Whether or not the image should be partially transparent.  If an
@@ -81,6 +76,16 @@ class Sprite:
        with the transparent color being the color of the top-rightmost
        pixel.
 
+    .. attribute:: origin_x
+
+       The suggested horizontal location of the origin relative to the
+       left edge of the images.
+
+    .. attribute:: origin_y
+
+       The suggested vertical location of the origin relative to the top
+       edge of the images.
+
     .. attribute:: fps
 
        The suggested rate in frames per second to animate the image at.
@@ -193,7 +198,7 @@ class Sprite:
         return len(self._baseimages)
 
     def __init__(self, name=None, ID=None, width=None, height=None,
-                 origin_x=0, origin_y=0, transparent=True, fps=60,
+                 transparent=True, origin_x=0, origin_y=0, fps=60,
                  bbox_x=None, bbox_y=None, bbox_width=None,
                  bbox_height=None):
         """Constructor method.
@@ -324,7 +329,7 @@ class Sprite:
 
                     img_w = max(1, sheet.get_width()) // n
                     img_h = max(1, sheet.get_height())
-                    for x in range(0, img_w * n, img_w):
+                    for x in xrange(0, img_w * n, img_w):
                         rect = pygame.Rect(x, 0, img_w, img_h)
                         img = sheet.subsurface(rect)
                         self._baseimages.append(img)
@@ -437,7 +442,7 @@ class Sprite:
 
         """
         color = sge._get_pygame_color(color)
-        for i in range(self.frames):
+        for i in xrange(self.frames):
             if frame is None or frame % self.frames == i:
                 self._baseimages[i].set_at((x, y), color)
 
@@ -468,7 +473,7 @@ class Sprite:
         color = sge._get_pygame_color(color)
         thickness = abs(thickness)
 
-        for i in range(self.frames):
+        for i in xrange(self.frames):
             if frame is None or frame % self.frames == i:
                 if anti_alias and thickness == 1:
                     pygame.draw.aaline(self._baseimages[i], color, (x1, y1),
@@ -510,7 +515,7 @@ class Sprite:
 
         rect = pygame.Rect(x, y, width, height)
 
-        for i in range(self.frames):
+        for i in xrange(self.frames):
             if frame is None or frame % self.frames == i:
                 if fill is not None:
                     pygame.draw.rect(self._baseimages[i],
@@ -555,7 +560,7 @@ class Sprite:
 
         rect = pygame.Rect(x, y, width, height)
 
-        for i in range(self.frames):
+        for i in xrange(self.frames):
             if frame is None or frame % self.frames == i:
                 if fill is not None:
                     c = sge._get_pygame_color(fill)
@@ -597,7 +602,7 @@ class Sprite:
             # There's no point in trying in this case.
             return
 
-        for i in range(self.frames):
+        for i in xrange(self.frames):
             if frame is None or frame % self.frames == i:
                 if fill is not None:
                     c = sge._get_pygame_color(fill)
@@ -669,7 +674,7 @@ class Sprite:
             sge.BLEND_RGB_MAXIMUM: pygame.BLEND_RGB_MAX
             }.setdefault(blend_mode, 0)
 
-        for i in range(self.frames):
+        for i in xrange(self.frames):
             if frame is None or frame % self.frames == i:
                 self._baseimages[i].blit(sprite._baseimages[image], (x, y),
                                          None, pygame_flags)
@@ -752,7 +757,7 @@ class Sprite:
         text_rect = text_surf.get_rect()
         box_rect = box_surf.get_rect()
 
-        for i in range(len(lines)):
+        for i in xrange(len(lines)):
             rendered_text = font._font.render(lines[i], anti_alias, color)
             rect = rendered_text.get_rect()
             rect.top = i * font._font.get_linesize()
@@ -793,7 +798,7 @@ class Sprite:
         else:
             box_rect.top = y
 
-        for i in range(self.frames):
+        for i in xrange(self.frames):
             if frame is None or frame % self.frames == i:
                 self._baseimages[i].blit(box_surf, box_rect)
 
@@ -808,7 +813,7 @@ class Sprite:
           the first frame; set to :const:`None` to clear all frames.
 
         """
-        for i in range(self.frames):
+        for i in xrange(self.frames):
             if frame is None or frame % self.frames == i:
                 if self._baseimages[i].get_flags() & pygame.SRCALPHA:
                     color = pygame.Color(0, 0, 0, 0)
@@ -840,7 +845,7 @@ class Sprite:
         reel = pygame.Surface((w, h), pygame.SRCALPHA)
         reel.fill(pygame.Color(0, 0, 0, 0))
 
-        for i in range(self.frames):
+        for i in xrange(self.frames):
             reel.blit(self._baseimages[i], (self.width * i, 0))
 
         try:
@@ -899,14 +904,14 @@ class Sprite:
                    bbox_height=bbox_height)
         tileset = Sprite(name, origin_x=x, origin_y=y)
 
-        for i in range(1, rows):
-            for j in range(1, columns):
+        for i in xrange(1, rows):
+            for j in xrange(1, columns):
                 self.append_frame()
 
         self.draw_clear()
 
-        for i in range(rows):
-            for j in range(columns):
+        for i in xrange(rows):
+            for j in xrange(columns):
                 frame = i * columns + j
                 x_ = (width + xsep) * j
                 y_ = (height + ysep) * i
@@ -972,7 +977,7 @@ class Sprite:
         # methods to work properly, specifically whenever ``width`` and
         # ``height`` are set.  As a result, setting ``width`` and
         # ``height`` is destructive in this implementation.
-        for i in range(self.frames):
+        for i in xrange(self.frames):
             if sge.game.scale_smooth:
                 try:
                     self._baseimages[i] = pygame.transform.smoothscale(
@@ -1066,15 +1071,15 @@ class Sprite:
             image.lock()
             mask = []
             if image.get_flags() & pygame.SRCALPHA:
-                for x in range(image.get_width()):
+                for x in xrange(image.get_width()):
                     mask.append([])
-                    for y in range(image.get_height()):
+                    for y in xrange(image.get_height()):
                         mask[x].append(image.get_at((x, y)).a > 0)
             else:
                 colorkey = image.get_colorkey()
-                for x in range(image.get_width()):
+                for x in xrange(image.get_width()):
                     mask.append([])
-                    for y in range(image.get_height()):
+                    for y in xrange(image.get_height()):
                         mask[x].append(image.get_at((x, y)) == colorkey)
 
             image.unlock()
