@@ -15,11 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with the Pygame SGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import os
 import sys
 import traceback
@@ -34,7 +29,7 @@ import sge
 __all__ = ['StellarClass', 'Mouse', '_PygameProjectionSprite']
 
 
-class StellarClass(object):
+class StellarClass:
 
     """Class for game objects.
 
@@ -354,7 +349,7 @@ class StellarClass(object):
     def detects_collisions(self, value):
         self._detects_collisions = value
         position = None
-        for i in xrange(len(sge.game._colliders)):
+        for i in range(len(sge.game._colliders)):
             if sge.game._colliders[i]() is self:
                 position = i
                 break
@@ -602,19 +597,19 @@ class StellarClass(object):
                     self.image_rotation)
             elif self.collision_ellipse:
                 # Elliptical mask based on bounding box.
-                mask = [[False for y in xrange(self.bbox_height)]
-                        for x in xrange(self.bbox_width)]
+                mask = [[False for y in range(self.bbox_height)]
+                        for x in range(self.bbox_width)]
                 a = len(mask) / 2
                 b = len(mask[0]) / 2 if mask else 0
 
-                for x in xrange(len(mask)):
-                    for y in xrange(len(mask[x])):
+                for x in range(len(mask)):
+                    for y in range(len(mask[x])):
                         if ((x - a) / a) ** 2 + ((y - b) / b) ** 2 <= 1:
                             mask[x][y] = True
             else:
                 # Mask is all pixels in the bounding box.
-                mask = [[True for y in xrange(self.bbox_height)]
-                        for x in xrange(self.bbox_width)]
+                mask = [[True for y in range(self.bbox_height)]
+                        for x in range(self.bbox_width)]
 
             self._masks[id_] = mask
             return mask
@@ -1461,7 +1456,7 @@ class StellarClass(object):
                 else:
                     room_area = room._collision_area_void
 
-                for i in xrange(len(room_area), 0, -1):
+                for i in range(len(room_area), 0, -1):
                     if room_area[i - 1]() is self:
                         del room_area[i - 1]
 
@@ -1484,7 +1479,7 @@ class StellarClass(object):
 
             # Delete self from the other object's list of colliders to
             # prevent redundancy.
-            for i in xrange(len(other._colliders)):
+            for i in range(len(other._colliders)):
                 if other._colliders[i]() is self:
                     del other._colliders[i]
                     break
@@ -1730,7 +1725,7 @@ class Mouse(StellarClass):
         self.mouse_yprevious = self.mouse_y
         self.previous_speeds = []
 
-        super(Mouse, self).__init__(0, 0, 0, ID='mouse')
+        super().__init__(0, 0, 0, ID='mouse')
 
     def event_collision(self, other):
         sge.game.event_mouse_collision(other)
@@ -1749,7 +1744,7 @@ class Mouse(StellarClass):
 
     def _update(self, time_passed, delta_mult):
         self.update_speed(time_passed)
-        super(Mouse, self)._update(time_passed, delta_mult)
+        super()._update(time_passed, delta_mult)
         self._update_collision_areas()
 
     def update_speed(self, time_passed):
@@ -1828,7 +1823,7 @@ class _PygameSprite(pygame.sprite.DirtySprite):
     def __init__(self, parent, *groups):
         # See pygame.sprite.DirtySprite.__init__.__doc__.  ``parent``
         # is a StellarClass object that this object belongs to.
-        super(_PygameSprite, self).__init__(*groups)
+        super().__init__(*groups)
         self.parent = weakref.ref(parent)
         self.image = pygame.Surface((1, 1))
         self.image.set_colorkey((0, 0, 0))
@@ -2005,7 +2000,7 @@ class _PygameOneTimeSprite(pygame.sprite.DirtySprite):
     # itself.
 
     def __init__(self, image, rect, *groups):
-        super(_PygameOneTimeSprite, self).__init__(*groups)
+        super().__init__(*groups)
         self.image = image
         self.rect = rect
         self.dirty = 1
