@@ -94,7 +94,7 @@ or ``"rEd"``.  The colors are:
 
 - ``"white"``
 - ``"silver"``
-- ``"gray``
+- ``"gray"``
 - ``"black"``
 - ``"red"``
 - ``"maroon"``
@@ -340,8 +340,8 @@ along with the Pygame SGE.  If not, see <http://www.gnu.org/licenses/>.
 Dependencies
 ------------
 
-- Python 2.7 <http://www.python.org>
-- Pygame 1.9.1 or later <http://pygame.org>
+- Python 3.1 or later <http://www.python.org>
+- Pygame 1.9.2 or later <http://pygame.org>
 
 Formats Support
 ---------------
@@ -411,12 +411,7 @@ by default.
 
 """
 
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
-__version__ = "0.9.0"
+__version__ = "0.9.1"
 
 import os
 
